# == Class: gnocchi
#
# Full description of class gnocchi here.
#
# === Parameters
#
# [*package_ensure*]
#   (optional) The state of gnocchi packages
#   Defaults to 'present'
#
# [*coordination_url*]
#   (optional) The url to use for distributed group membership coordination.
#   Defaults to $::os_service_default.
#
# [*purge_config*]
#   (optional) Whether to set only the specified config options
#   in the gnocchi config.
#   Defaults to false.
#
class gnocchi (
  $package_ensure            = 'present',
  $coordination_url          = $::os_service_default,
  $package_ensure            = 'present',
  $coordination_url          = $::os_service_default,
  $coordination_url_metricd  = $::os_service_default,
  $purge_config              = false,
  $use_multiple_config_files = false,
) inherits gnocchi::params {

  include gnocchi::deps

  if $use_multiple_config_files {
    package { 'gnocchi':
      ensure => $package_ensure,
      name   => $::gnocchi::params::common_package_name,
      tag    => ['openstack', 'gnocchi-package'],
    }
    ~> exec { 'copy /etc/gnocchi/gnocchi-metricd.conf':
      command => '/usr/bin/cp /usr/share/gnocchi-common/gnocchi.conf /etc/gnocchi/gnocchi-metricd.conf && /usr/bin/chown root:gnocchi /etc/gnocchi/gnocchi-metricd.conf && /usr/bin/chmod 640 /etc/gnocchi/gnocchi-metricd.conf',
      creates => '/etc/gnocchi/gnocchi-metricd.conf',
    }
    ~> exec { 'copy /etc/gnocchi/gnocchi-api.conf':
      command => '/usr/bin/cp /usr/share/gnocchi-common/gnocchi.conf /etc/gnocchi/gnocchi-api.conf && /usr/bin/chown root:gnocchi /etc/gnocchi/gnocchi-api.conf && /usr/bin/chmod 640 /etc/gnocchi/gnocchi-api.conf',
      creates => '/etc/gnocchi/gnocchi-api.conf',
    }
  } else {
    package { 'gnocchi':
      ensure => $package_ensure,
      name   => $::gnocchi::params::common_package_name,
      tag    => ['openstack', 'gnocchi-package'],
    }
    ~> file{ '/etc/gnocchi/gnocchi-api.conf':
      ensure => absent,
    }
    ~> file{ '/etc/gnocchi/gnocchi-metricd.conf':
      ensure => absent,
    }
  }

  resources { 'gnocchi_config':
    purge => $purge_config,
  }

  if $coordination_url_real {

    if $use_multiple_config_files == true {
      gnocchi_api_config {
        'DEFAULT/coordination_url' : value => $coordination_url_real;
      }
      gnocchi_metricd_config {
        'DEFAULT/coordination_url' : value => $coordination_url_metricd;
      }
      gnocchi_config {
        'DEFAULT/coordination_url' : value => $::os_service_default;
      }
      ensure_resource('package', 'python-redis', {
        ensure => $storage_package_ensure,
        name   => $::gnocchi::params::redis_package_name,
        tag    => 'openstack',
      })
    } else {
      gnocchi_config {
        'DEFAULT/coordination_url' : value => $coordination_url_real;
      }
      if ($coordination_url_real =~ /^redis/ ) {
        ensure_resource('package', 'python-redis', {
          ensure => $storage_package_ensure,
          name   => $::gnocchi::params::redis_package_name,
          tag    => 'openstack',
        })
      }
    }

  }
}
